﻿using System.Windows;

using Prism.Ioc;
using Prism.Regions;
using Unity;

namespace TestProject.Views
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 컨테이너 확장 인터페이스
        /// </summary>
        private IContainerExtension containerExtension;

        /// <summary>
        /// 영역 관리자 인터페이스
        /// </summary>
        private IRegionManager regionManager;

        /// <summary>
        /// 영역 인터페이스
        /// </summary>
        private IRegion region;

        /// <summary>
        /// 뷰 A
        /// </summary>
        private ViewA viewA;

        /// <summary>
        /// 뷰 B
        /// </summary>
        private ViewB viewB;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow(container, regionManager)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="containerExtension">컨테이너 확장 인터페이스</param>
        /// <param name="regionManager">영역 관리자 인터페이스</param>
        public MainWindow(IContainerExtension containerExtension, IRegionManager regionManager)
        {
            InitializeComponent();

            this.containerExtension = containerExtension;
            this.regionManager      = regionManager;

            Loaded += Window_Loaded;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            this.viewA = this.containerExtension.Resolve<ViewA>();
            this.viewB = this.containerExtension.Resolve<ViewB>();

            this.region = this.regionManager.Regions["ContentRegion"];

            this.region.Add(viewA);
            this.region.Add(viewB);
        }

        #endregion
        #region View A 활성화 버튼 클릭시 처리하기 - activateViewAButton_Click(sender, e)

        /// <summary>
        /// View A 활성화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void activateViewAButton_Click(object sender, RoutedEventArgs e)
        {
            this.region.Activate(this.viewA);
        }

        #endregion
        #region View A 비활성화 버튼 클릭시 처리하기 - deactivateViewAButton_Click(sender, e)

        /// <summary>
        /// View A 비활성화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void deactivateViewAButton_Click(object sender, RoutedEventArgs e)
        {
            this.region.Deactivate(this.viewA);
        }

        #endregion
        #region View B 활성화 버튼 클릭시 처리하기 - activateViewBButton_Click(sender, e)

        /// <summary>
        /// View B 활성화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void activateViewBButton_Click(object sender, RoutedEventArgs e)
        {
            this.region.Activate(this.viewB);
        }

        #endregion
        #region View B 비활성화 버튼 클릭시 처리하기 - deactivateViewBButton_Click(sender, e)

        /// <summary>
        /// View B 비활성화 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void deactivateViewBButton_Click(object sender, RoutedEventArgs e)
        {
            this.region.Deactivate(this.viewB);
        }

        #endregion
    }
}